#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
userprovided library
~~~~~~~~~~~~~~~~~~~~~
Source: https://github.com/RuedigerVoigt/userprovided
(c) 2020-2021 Rüdiger Voigt
Released under the Apache License 2.0
"""

from userprovided import cloud
from userprovided import date
from userprovided import hash
from userprovided import mail
from userprovided import parameters
from userprovided import port
from userprovided import url


name = "userprovided"
__version__ = "0.8.0"
__author__ = "Rüdiger Voigt"
